/*
 * This file is part of the Nepomuk KDE project.
 * Copyright (C) 2008 Adrien Bustany <madcat@mymadcat.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef ANNOTATIONPROPERTY_H
#define ANNOTATIONPROPERTY_H

#include <QtCore/QSharedDataPointer>
#include <QtGui/QPixmap>
#include <Nepomuk/Types/Property>
#include <nepomuk/nepomuk_export.h>

namespace Nepomuk {

class AnnotationPlugin;

/**
 * \class AnnotationProperty annotationproperty.h AnnotationProperty
 * \brief This class describes a property linking two resources together, as well as the relevance (specificity
 * of this relation. It's basically a Nepomuk::Types::Property+relevance bundle.
 *
 * This class uses a shared data implementation.
 *
 * \author Adrien Bustany <madcat@mymadcat.com>
 */
class NEPOMUK_EXPORT AnnotationProperty
{

public:
	/**
	 * Creates a new, empty AnnotationProperty
	 */
	AnnotationProperty(AnnotationPlugin* parent = 0);

	/**
	 * Creates an AnnotationProperty and fills it with the given property and relevance
	 */
	AnnotationProperty(AnnotationPlugin* parent, const Types::Property& property, int relevance, const QPixmap& icon = QPixmap());

	/**
	 * Creates an AnnotationProperty and fills it with the property having the given uri, and the given relevance
	 */
	AnnotationProperty(AnnotationPlugin* parent, const QUrl& uri, int relevance, const QPixmap& icon = QPixmap());
	AnnotationProperty(const AnnotationProperty& other);
	AnnotationProperty& operator=(const AnnotationProperty& other);
	~AnnotationProperty();

	Types::Property property() const;

	QString label() const;
	void setLabel(const QString& label);

	QString description() const;
	void setDescription(const QString& description);

	int relevance() const;
	QPixmap icon() const;
	AnnotationPlugin* parent() const;

private:
	class Private;
	QSharedDataPointer<Private> d;

};

} // End namespace Nepomuk

#endif
