/* 
   Copyright (c) 2008 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef _NEPOMUK_CONTACT_H_
#define _NEPOMUK_CONTACT_H_

#include <QtCore/QSharedDataPointer>
#include <QtCore/QList>

#include <nepomuk/resource.h>
#include <nepomuk/nepomuk_export.h>

namespace Nepomuk {
    namespace PIM {
        class NEPOMUK_EXPORT Contact
        {
        public:
            Contact();
            Contact( const Contact& );
            ~Contact();

            Contact& operator=( const Contact& );

            bool isValid() const;

            static Contact queryPersonByName( const QString& name, bool create = false );
            static Contact queryPersonByEmail( const QString& emailAddress, bool create = false );
            static Contact queryPersonByIdentifier( const QUrl& idType, const QString& identifier, bool create = false );
//            static Contact queryPersonByAkonadiItem( const QString& item, bool create = false );

            QString name() const;
            QString emailAddress() const;
            QString identifier( const QUrl& idTyoe ) const;

            void setName( const QString& name );

            Variant property( const QUrl& property ) const;

            Thing pimoThing() const;
            QList<Resource> incarnations() const;

            void addIncarnation( const QUrl& idType, const QString& id );

        private:
            class Private;
            QSharedDataPointer<Private> d;
        };
    }
}

#endif
