/* This file is part of the Nepomuk Project
   Copyright (c) 2008 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef _NEPOMUK_SIMPLE_ANNOTATION_H_
#define _NEPOMUK_SIMPLE_ANNOTATION_H_

#include "annotation.h"
#include "nepomuk_export.h"

class QUrl;

namespace Nepomuk {

    class Variant;
    namespace Types {
        class Property;
    }

    /**
     * takes parameters property and value and does automatic statistics.
     */
    class NEPOMUK_EXPORT SimpleAnnotation : public Annotation
    {
        Q_OBJECT

    public:
        SimpleAnnotation( const Resource& resource, QObject* parent = 0 );
        SimpleAnnotation( const Resource& resource, const Types::Property& prop, const Variant& object, QObject* parent = 0 );
        virtual ~SimpleAnnotation();

        /**
         * Will also set the icon using Types::Property::icon()
         */
        void setProperty( const Types::Property& );

        /**
         * Setting a new property label means that a new property will be
         * created before annotation the resource with it.
         */
        void setNewPropertyLabel( const QString& s );

        void setValue( const Variant& value );

        Types::Property property() const;
        Variant value() const;
        QString newPropertyLabel() const;

        virtual int occurenceCount( const QDateTime& from = QDateTime(), const QDateTime& to = QDateTime() ) const;
        virtual QDateTime lastUsed() const;
        virtual QDateTime firstUsed() const;

    protected:
        /**
         * Simply annotates the thing of the set resource with the property
         * and value as passed to the constructor.
         */
        virtual void doCreate();

    private:
        class Private;
        Private* const d;
    };
}

#endif
